@@ -1,8 +1,6 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
 
 class ParameterMatcherTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -264,7 +262,7 @@ class ParameterMatcherTest < Mocha::TestCase
   def test_should_match_parameter_when_value_is_divisible_by_four
     test_result = run_as_test do
       mock = mock()
-      mock.expects(:method).with { |actual_value| actual_value % 4 == 0 }
+      mock.expects(:method).with { |actual_value| (actual_value % 4).zero? }
       mock.method(8)
     end
     assert_passed(test_result)
@@ -273,7 +271,7 @@ class ParameterMatcherTest < Mocha::TestCase
   def test_should_not_match_parameter_when_value_is_not_divisible_by_four
     test_result = run_as_test do
       mock = mock()
-      mock.expects(:method).with { |actual_value| actual_value % 4 == 0 }
+      mock.expects(:method).with { |actual_value| (actual_value % 4).zero? }
       mock.method(9)
     end
     assert_failed(test_result)
