@@ -1,8 +1,6 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha'
-
-class RaiseExceptionTest < Test::Unit::TestCase
 
+class RaiseExceptionTest < Mocha::TestCase
   include AcceptanceTest
 
   def setup
@@ -17,9 +15,9 @@ class RaiseExceptionTest < Test::Unit::TestCase
     exception_class = Class.new(StandardError)
     test_result = run_as_test do
       foo = stub('foo')
-      foo.stubs(:bar).raises(exception_class, "my-message")
+      foo.stubs(:bar).raises(exception_class, 'my-message')
       exception = assert_raises(exception_class) { foo.bar }
-      assert_equal "my-message", exception.message
+      assert_equal 'my-message', exception.message
     end
     assert_passed(test_result)
   end
@@ -35,5 +33,4 @@ class RaiseExceptionTest < Test::Unit::TestCase
     end
     assert_passed(test_result)
   end
-
-end
\ No newline at end of file
+end
