@@ -1,9 +1,7 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
 require 'execution_point'
 
 class StubbingErrorBacktraceTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -14,10 +12,11 @@ class StubbingErrorBacktraceTest < Mocha::TestCase
     teardown_acceptance_test
   end
 
+  # rubocop:disable Style/Semicolon
   def test_should_display_backtrace_indicating_line_number_where_attempt_to_stub_non_existent_method_was_made
     execution_point = nil
     object = Object.new
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; object.stubs(:non_existent_method)
     end
@@ -31,7 +30,7 @@ class StubbingErrorBacktraceTest < Mocha::TestCase
       def non_public_method; end
       private :non_public_method
     end.new
-    Mocha::Configuration.prevent(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :prevent }
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; object.stubs(:non_public_method)
     end
@@ -42,7 +41,7 @@ class StubbingErrorBacktraceTest < Mocha::TestCase
   def test_should_display_backtrace_indicating_line_number_where_attempt_to_stub_method_on_non_mock_object_was_made
     execution_point = nil
     object = Object.new
-    Mocha::Configuration.prevent(:stubbing_method_on_non_mock_object)
+    Mocha.configure { |c| c.stubbing_method_on_non_mock_object = :prevent }
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; object.stubs(:any_method)
     end
@@ -53,12 +52,12 @@ class StubbingErrorBacktraceTest < Mocha::TestCase
   def test_should_display_backtrace_indicating_line_number_where_method_was_unnecessarily_stubbed
     execution_point = nil
     object = Object.new
-    Mocha::Configuration.prevent(:stubbing_method_unnecessarily)
+    Mocha.configure { |c| c.stubbing_method_unnecessarily = :prevent }
     test_result = run_as_test do
       execution_point = ExecutionPoint.current; object.stubs(:unused_method)
     end
     assert_equal 1, test_result.error_count
     assert_equal execution_point, ExecutionPoint.new(test_result.errors[0].exception.backtrace)
   end
-
+  # rubocop:enable Style/Semicolon
 end
