@@ -1,5 +1,5 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
+require 'mocha/configuration'
 
 class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   include AcceptanceTest
@@ -13,7 +13,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_non_existent_instance_method
-    Mocha::Configuration.allow(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :allow }
     instance = Class.new.new
     test_result = run_as_test do
       instance.stubs(:non_existent_method)
@@ -23,7 +23,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_warn_when_stubbing_non_existent_instance_method
-    Mocha::Configuration.warn_when(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :warn }
     instance = Class.new.new
     test_result = run_as_test do
       instance.stubs(:non_existent_method)
@@ -33,7 +33,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_prevent_stubbing_non_existent_instance_method
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     instance = Class.new.new
     test_result = run_as_test do
       instance.stubs(:non_existent_method)
@@ -52,7 +52,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_existing_public_instance_method
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     klass = Class.new do
       def existing_public_method; end
       public :existing_public_method
@@ -65,9 +65,9 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_method_to_which_instance_responds
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     klass = Class.new do
-      def respond_to?(method, _include_private = false)
+      def respond_to?(method, _include_all = false)
         (method == :method_to_which_instance_responds)
       end
     end
@@ -79,7 +79,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_existing_protected_instance_method
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     klass = Class.new do
       def existing_protected_method; end
       protected :existing_protected_method
@@ -92,7 +92,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_existing_private_instance_method
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     klass = Class.new do
       def existing_private_method; end
       private :existing_private_method
@@ -105,7 +105,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_existing_public_instance_superclass_method
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     superklass = Class.new do
       def existing_public_method; end
       public :existing_public_method
@@ -118,7 +118,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_existing_protected_instance_superclass_method
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     superklass = Class.new do
       def existing_protected_method; end
       protected :existing_protected_method
@@ -131,7 +131,7 @@ class StubbingNonExistentInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_existing_private_instance_superclass_method
-    Mocha::Configuration.prevent(:stubbing_non_existent_method)
+    Mocha.configure { |c| c.stubbing_non_existent_method = :prevent }
     superklass = Class.new do
       def existing_private_method; end
       private :existing_private_method
