@@ -1,8 +1,7 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
+require 'mocha/configuration'
 
 class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -14,7 +13,7 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_private_any_instance_method
-    Mocha::Configuration.allow(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :allow }
     klass = Class.new do
       def private_method; end
       private :private_method
@@ -27,7 +26,7 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_protected_any_instance_method
-    Mocha::Configuration.allow(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :allow }
     klass = Class.new do
       def protected_method; end
       protected :protected_method
@@ -40,7 +39,7 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_warn_when_stubbing_private_any_instance_method
-    Mocha::Configuration.warn_when(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :warn }
     klass = Class.new do
       def private_method; end
       private :private_method
@@ -53,7 +52,7 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_warn_when_stubbing_protected_any_instance_method
-    Mocha::Configuration.warn_when(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :warn }
     klass = Class.new do
       def protected_method; end
       protected :protected_method
@@ -66,7 +65,7 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_prevent_stubbing_private_any_instance_method
-    Mocha::Configuration.prevent(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :prevent }
     klass = Class.new do
       def private_method; end
       private :private_method
@@ -79,7 +78,7 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_prevent_stubbing_protected_any_instance_method
-    Mocha::Configuration.prevent(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :prevent }
     klass = Class.new do
       def protected_method; end
       protected :protected_method
@@ -116,7 +115,7 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
   end
 
   def test_should_allow_stubbing_public_any_instance_method
-    Mocha::Configuration.prevent(:stubbing_non_public_method)
+    Mocha.configure { |c| c.stubbing_non_public_method = :prevent }
     klass = Class.new do
       def public_method; end
       public :public_method
@@ -126,5 +125,4 @@ class StubbingNonPublicAnyInstanceMethodTest < Mocha::TestCase
     end
     assert_passed(test_result)
   end
-
 end
