@@ -1,8 +1,6 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/setup'
 
 class UnstubbingTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -15,7 +13,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_an_instance_method_should_restore_original_behaviour
     klass = Class.new do
-      def my_instance_method; :original_return_value; end
+      def my_instance_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       object = klass.new
@@ -28,7 +28,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_class_method_should_restore_original_behaviour
     klass = Class.new do
-      def self.my_class_method; :original_return_value; end
+      def self.my_class_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       klass.stubs(:my_class_method).returns(:new_return_value)
@@ -40,7 +42,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_module_method_should_restore_original_behaviour
     mod = Module.new do
-      def self.my_module_method; :original_return_value; end
+      def self.my_module_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       mod.stubs(:my_module_method).returns(:new_return_value)
@@ -52,7 +56,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_module_method_defined_like_fileutils_in_ruby_2_0_should_restore_original_behaviour
     mod = Module.new do
-      def my_module_method; :original_return_value; end
+      def my_module_method
+        :original_return_value
+      end
       private :my_module_method
       extend self
       class << self
@@ -69,7 +75,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_an_any_instance_method_should_restore_original_behaviour
     klass = Class.new do
-      def my_instance_method; :original_return_value; end
+      def my_instance_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       object = klass.new
@@ -82,8 +90,13 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_multiple_methods_should_restore_original_behaviour
     klass = Class.new do
-      def my_first_instance_method; :original_return_value; end
-      def my_second_instance_method; :original_return_value; end
+      def my_first_instance_method
+        :original_return_value
+      end
+
+      def my_second_instance_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       object = klass.new
@@ -98,7 +111,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_method_multiple_times_should_restore_original_behaviour
     klass = Class.new do
-      def my_instance_method; :original_return_value; end
+      def my_instance_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       object = klass.new
@@ -112,7 +127,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_non_stubbed_method_should_do_nothing
     klass = Class.new do
-      def my_instance_method; :original_return_value; end
+      def my_instance_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       object = klass.new
@@ -124,7 +141,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_method_which_was_stubbed_multiple_times_should_restore_orginal_behaviour
     klass = Class.new do
-      def my_instance_method; :original_return_value; end
+      def my_instance_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       object = klass.new
@@ -138,8 +157,13 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_method_should_not_unstub_other_stubbed_methods
     klass = Class.new do
-      def my_first_instance_method; :first_return_value; end
-      def my_second_instance_method; :second_return_value; end
+      def my_first_instance_method
+        :first_return_value
+      end
+
+      def my_second_instance_method
+        :second_return_value
+      end
     end
 
     test_result = run_as_test do
@@ -155,7 +179,9 @@ class UnstubbingTest < Mocha::TestCase
 
   def test_unstubbing_a_method_should_remove_all_expectations_for_that_method
     klass = Class.new do
-      def my_instance_method; :original_return_value; end
+      def my_instance_method
+        :original_return_value
+      end
     end
     test_result = run_as_test do
       object = klass.new
