@@ -1,7 +1,7 @@
 require File.expand_path('../../test_helper', __FILE__)
 
-require "mocha/mini_test"
-require "integration/shared_tests"
+require 'mocha/minitest'
+require 'integration/shared_tests'
 
 class MiniTestTest < Mocha::TestCase
   include SharedTests
