@@ -4,7 +4,6 @@ require 'mocha/parameter_matchers/is_a'
 require 'mocha/inspect'
 
 class IsATest < Mocha::TestCase
-
   include Mocha::ParameterMatchers
 
   def test_should_match_object_that_is_a_specified_class
@@ -19,7 +18,6 @@ class IsATest < Mocha::TestCase
 
   def test_should_describe_matcher
     matcher = is_a(Integer)
-    assert_equal "is_a(Integer)", matcher.mocha_inspect
+    assert_equal 'is_a(Integer)', matcher.mocha_inspect
   end
-
 end
